Crate ahum_dialoguer

Crate ahum_dialoguer 

dialoguer is a library for Rust that helps you build useful small interactive user inputs for the command line. It provides utilities to render various simple dialogs like confirmation prompts, text inputs and more.

Best paired with other libraries in the family:

Crate Contents

  • Confirmation prompts
  • Input prompts (regular and password)
  • Input validation
  • Menu selections
  • Checkboxes
  • Editor launching

Modules

theme
Customizes the rendering of the elements.

Structs

Checkboxes
Renders a multi select checkbox menu.
Confirmation
Renders a simple confirmation prompt.
Editor
Launches the default editor edit a string.
FileInput
Renders a file input
Input
Renders a simple input prompt.
PasswordInput
Renders a password input prompt.
Select
Renders a selection menu.

Traits

Validator